@@ -1,6 +1,7 @@
 import pyarrow.parquet as pq
 import pyarrow as pa
 
+
 class SymbolSearcher:
     def __init__(self, index_path):
         self.table = pq.read_table(index_path)
@@ -25,19 +26,13 @@ class SymbolSearcher:
         for i in indexes:
             id_value = ids[i]
             kind_value = self.table.column('kind')[i]
-            start_line = self.table.column('start_line')[i]
-            start_col = self.table.column('start_col')[i]
-            end_line = self.table.column('end_line')[i]
-            end_col = self.table.column('end_col')[i]
+            range_value = self.table.column('range')[i]
+            relative_path_value = self.table.column('file_path')[i]
+
             result.append({
                 'id': id_value.as_py(),
                 'kind': kind_value.as_py(),
-                'start_line': start_line.as_py(),
-                'start_col': start_col.as_py(),
-                'end_line': end_line.as_py(),
-                'end_col': end_col.as_py()
+                'range': range_value.as_py(),
+                'file_path': relative_path_value.as_py()
             })
         return result
-
-
-
